@@ -1,7 +1,6 @@
 import argparse
 import os
-
-from .common import XmlReader,ExcelMaker,valid_programs
+from case.common import ExcelMaker,valid_programs,XmlReader        
     
 def generate_file(program_code,excel_file):
     em=ExcelMaker(program_code)
@@ -14,8 +13,6 @@ def main():
     parser.add_argument("-t", "--to", help="input excel file name for output")
     args = parser.parse_args()
     
-    # 输入program code, xml文件，以及输出excel文件。
-    # 如果excel文件不存在，那么根据program code创建该文件，然后写入读取的数据
     if args.program and args.xml and args.to:
         if args.program not in valid_programs:
             print(f'Your input program code {args.program} is not valid. ')
